.. _api:

API
***

   :Release: |release|
   :Date: |today|
   :Backend Release: |BackendVersion|

.. toctree::
   :maxdepth: 2

   introduction
   interfaces
   graph_factories
   property_graph_factories
   views
   traversals
   properties
   metrics
   algorithms/index
   generators
   io/index
